==> koffice2_1.9.93.orig.tar.gz: koffice-1.9.93/krita/ui/kis_opengl_fragment_shader.h <==
/*
 *  Copyright (c) 2007 Adrian Page <adrian@pagenet.plus.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
#ifndef KIS_OPENGL_FRAGMENT_SHADER_H_
#define KIS_OPENGL_FRAGMENT_SHADER_H_

#include <QString>

#include "krita_export.h"
#include "kis_opengl_shader.h"

/**
 * An encapsulation of an OpenGL Shading Language fragment shader object. 
 */
class KRITAUI_EXPORT KisOpenGLFragmentShader : public KisOpenGLShader {
public:

    /**
     * Loads the shader source code from the given file, which will be searched 
     * for in the 'kis_shaders' resource directory (krita/data/shaders).
     * Refer to KisOpenGLShader for more information.
     * @param sourceCodeFilename the file to read the source code from
     */
    KisOpenGLFragmentShader(const QString& sourceCodeFilename);
};

#endif // KIS_OPENGL_FRAGMENT_SHADER_H_

==> koffice2_1.9.95.orig.tar.gz: koffice-1.9.95/krita/ui/kis_opengl_fragment_shader.h <==
/*
 *  Copyright (c) 2007 Adrian Page <adrian@pagenet.plus.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
#ifndef KIS_OPENGL_FRAGMENT_SHADER_H_
#define KIS_OPENGL_FRAGMENT_SHADER_H_

#include <QString>

#include "krita_export.h"
#include "kis_opengl_shader.h"

/**
 * An encapsulation of an OpenGL Shading Language fragment shader object. 
 */
class KRITAUI_EXPORT KisOpenGLFragmentShader : public KisOpenGLShader {
public:

    /**
     * Loads the shader source code from the given file, which will be searched 
     * for in the 'kis_shaders' resource directory (krita/data/shaders).
     * Refer to KisOpenGLShader for more information.
     * @param sourceCodeFilename the file to read the source code from
     */
    KisOpenGLFragmentShader(const QString& sourceCodeFilename);

    /**
     * Loads the shader source code from the given QVector<QString>
     *
     * @param sourceCodeStrings the vector of source strings to load from
     */
    KisOpenGLFragmentShader(const QVector<QString> &sourceCodeStrings);
};

#endif // KIS_OPENGL_FRAGMENT_SHADER_H_
